From 39edfec85487f7de81fbade3c31bf2de4fabff9f Mon Sep 17 00:00:00 2001
From: redray <redray@ispconfig3>
Date: Mon, 15 Dec 2008 13:04:21 -0500
Subject: [PATCH] removed "options indexes"
---
interface/web/client/client_edit.php | 91 ++++++++++++++++++++++++++++++++++++++++++---
1 files changed, 84 insertions(+), 7 deletions(-)
diff --git a/interface/web/client/client_edit.php b/interface/web/client/client_edit.php
index d66d612..23e445f 100644
--- a/interface/web/client/client_edit.php
+++ b/interface/web/client/client_edit.php
@@ -41,16 +41,93 @@
require_once('../../lib/config.inc.php');
require_once('../../lib/app.inc.php');
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
- header("Location: ../index.php");
- exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('client');
// Loading classes
$app->uses('tpl,tform,tform_actions');
+$app->load('tform_actions');
-// let tform_actions handle the page
-$app->tform_actions->onLoad();
+class page_action extends tform_actions {
+
+ /*
+ This function is called automatically right after
+ the data was successful inserted in the database.
+ */
+ function onAfterInsert() {
+ global $app;
+ // Create the group for the client
+ $sql = "INSERT INTO sys_group (name,description,client_id) VALUES ('".mysql_real_escape_string($this->dataRecord["username"])."','',".$this->id.")";
+ $app->db->query($sql);
+ $groupid = $app->db->insertID();
+ $groups = $groupid;
+
+ $username = mysql_real_escape_string($this->dataRecord["username"]);
+ $password = mysql_real_escape_string($this->dataRecord["password"]);
+ $modules = ISPC_INTERFACE_MODULES_ENABLED;
+ if($this->dataRecord["limit_client"] > 0) $modules .= ',client';
+ $startmodule = 'mail';
+ $usertheme = mysql_real_escape_string($this->dataRecord["usertheme"]);
+ $type = 'user';
+ $active = 1;
+ $language = mysql_real_escape_string($this->dataRecord["language"]);
+
+ // Create the controlpaneluser for the client
+ $sql = "INSERT INTO sys_user (username,passwort,modules,startmodule,app_theme,typ,active,language,groups,default_group,client_id)
+ VALUES ('$username',md5('$password'),'$modules','$startmodule','$usertheme','$type','$active','$language',$groups,$groupid,".$this->id.")";
+ $app->db->query($sql);
+
+ //* If the user who inserted the client is a reseller (not admin), we will have to add this new client group
+ //* to his groups, so he can administrate the records of this client.
+ if($_SESSION['s']['user']['typ'] == 'user') {
+ $app->auth->add_group_to_user($_SESSION['s']['user']['userid'],$groupid);
+ $app->db->query("UPDATE client SET parent_client_id = ".intval($_SESSION['s']['user']['client_id'])." WHERE client_id = ".$this->id);
+ }
+
+
+ }
+
+
+ /*
+ This function is called automatically right after
+ the data was successful updated in the database.
+ */
+ function onAfterUpdate() {
+ global $app;
+
+ // username changed
+ if(isset($app->tform->diffrec['username'])) {
+ $username = mysql_real_escape_string($this->dataRecord["username"]);
+ $client_id = $this->id;
+ $sql = "UPDATE sys_user SET username = '$username' WHERE client_id = $client_id";
+ $app->db->query($sql);
+ $sql = "UPDATE sys_group SET name = '$username' WHERE client_id = $client_id";
+ $app->db->query($sql);
+ }
+
+ // password changed
+ if(isset($this->dataRecord["password"]) && $this->dataRecord["password"] != '') {
+ $password = mysql_real_escape_string($this->dataRecord["password"]);
+ $client_id = $this->id;
+ $sql = "UPDATE sys_user SET passwort = md5('$password') WHERE client_id = $client_id";
+ $app->db->query($sql);
+ }
+
+ // reseller status changed
+ if(isset($this->dataRecord["limit_client"])) {
+ $modules = ISPC_INTERFACE_MODULES_ENABLED;
+ if($this->dataRecord["limit_client"] > 0) $modules .= ',client';
+ $modules = mysql_real_escape_string($modules);
+ $client_id = $this->id;
+ $sql = "UPDATE sys_user SET modules = '$modules' WHERE client_id = $client_id";
+ $app->db->query($sql);
+ }
+ }
+
+
+}
+
+$page = new page_action;
+$page->onLoad();
?>
\ No newline at end of file
--
Gitblit v1.9.1